'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_envmap_bumpmap'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_envmap_bumpmap',error_checker=_errors._error_checker)
GL_BUMP_ENVMAP_ATI=_C('GL_BUMP_ENVMAP_ATI',0x877B)
GL_BUMP_NUM_TEX_UNITS_ATI=_C('GL_BUMP_NUM_TEX_UNITS_ATI',0x8777)
GL_BUMP_ROT_MATRIX_ATI=_C('GL_BUMP_ROT_MATRIX_ATI',0x8775)
GL_BUMP_ROT_MATRIX_SIZE_ATI=_C('GL_BUMP_ROT_MATRIX_SIZE_ATI',0x8776)
GL_BUMP_TARGET_ATI=_C('GL_BUMP_TARGET_ATI',0x877C)
GL_BUMP_TEX_UNITS_ATI=_C('GL_BUMP_TEX_UNITS_ATI',0x8778)
GL_DU8DV8_ATI=_C('GL_DU8DV8_ATI',0x877A)
GL_DUDV_ATI=_C('GL_DUDV_ATI',0x8779)
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetTexBumpParameterfvATI(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glGetTexBumpParameterivATI(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glTexBumpParameterfvATI(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glTexBumpParameterivATI(pname,param):pass
