'''OpenGL extension EXT.shadow_funcs

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.shadow_funcs to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension generalizes the GL_ARB_shadow extension to support all
	eight binary texture comparison functions rather than just GL_LEQUAL
	and GL_GEQUAL.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/shadow_funcs.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.shadow_funcs import *
from OpenGL.raw.GL.EXT.shadow_funcs import _EXTENSION_NAME

def glInitShadowFuncsEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION