'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_EXT_texture_from_pixmap'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_EXT_texture_from_pixmap',error_checker=_errors._error_checker)
GLX_AUX0_EXT=_C('GLX_AUX0_EXT',0x20E2)
GLX_AUX1_EXT=_C('GLX_AUX1_EXT',0x20E3)
GLX_AUX2_EXT=_C('GLX_AUX2_EXT',0x20E4)
GLX_AUX3_EXT=_C('GLX_AUX3_EXT',0x20E5)
GLX_AUX4_EXT=_C('GLX_AUX4_EXT',0x20E6)
GLX_AUX5_EXT=_C('GLX_AUX5_EXT',0x20E7)
GLX_AUX6_EXT=_C('GLX_AUX6_EXT',0x20E8)
GLX_AUX7_EXT=_C('GLX_AUX7_EXT',0x20E9)
GLX_AUX8_EXT=_C('GLX_AUX8_EXT',0x20EA)
GLX_AUX9_EXT=_C('GLX_AUX9_EXT',0x20EB)
GLX_BACK_EXT=_C('GLX_BACK_EXT',0x20E0)
GLX_BACK_LEFT_EXT=_C('GLX_BACK_LEFT_EXT',0x20E0)
GLX_BACK_RIGHT_EXT=_C('GLX_BACK_RIGHT_EXT',0x20E1)
GLX_BIND_TO_MIPMAP_TEXTURE_EXT=_C('GLX_BIND_TO_MIPMAP_TEXTURE_EXT',0x20D2)
GLX_BIND_TO_TEXTURE_RGBA_EXT=_C('GLX_BIND_TO_TEXTURE_RGBA_EXT',0x20D1)
GLX_BIND_TO_TEXTURE_RGB_EXT=_C('GLX_BIND_TO_TEXTURE_RGB_EXT',0x20D0)
GLX_BIND_TO_TEXTURE_TARGETS_EXT=_C('GLX_BIND_TO_TEXTURE_TARGETS_EXT',0x20D3)
GLX_FRONT_EXT=_C('GLX_FRONT_EXT',0x20DE)
GLX_FRONT_LEFT_EXT=_C('GLX_FRONT_LEFT_EXT',0x20DE)
GLX_FRONT_RIGHT_EXT=_C('GLX_FRONT_RIGHT_EXT',0x20DF)
GLX_MIPMAP_TEXTURE_EXT=_C('GLX_MIPMAP_TEXTURE_EXT',0x20D7)
GLX_TEXTURE_1D_BIT_EXT=_C('GLX_TEXTURE_1D_BIT_EXT',0x00000001)
GLX_TEXTURE_1D_EXT=_C('GLX_TEXTURE_1D_EXT',0x20DB)
GLX_TEXTURE_2D_BIT_EXT=_C('GLX_TEXTURE_2D_BIT_EXT',0x00000002)
GLX_TEXTURE_2D_EXT=_C('GLX_TEXTURE_2D_EXT',0x20DC)
GLX_TEXTURE_FORMAT_EXT=_C('GLX_TEXTURE_FORMAT_EXT',0x20D5)
GLX_TEXTURE_FORMAT_NONE_EXT=_C('GLX_TEXTURE_FORMAT_NONE_EXT',0x20D8)
GLX_TEXTURE_FORMAT_RGBA_EXT=_C('GLX_TEXTURE_FORMAT_RGBA_EXT',0x20DA)
GLX_TEXTURE_FORMAT_RGB_EXT=_C('GLX_TEXTURE_FORMAT_RGB_EXT',0x20D9)
GLX_TEXTURE_RECTANGLE_BIT_EXT=_C('GLX_TEXTURE_RECTANGLE_BIT_EXT',0x00000004)
GLX_TEXTURE_RECTANGLE_EXT=_C('GLX_TEXTURE_RECTANGLE_EXT',0x20DD)
GLX_TEXTURE_TARGET_EXT=_C('GLX_TEXTURE_TARGET_EXT',0x20D6)
GLX_Y_INVERTED_EXT=_C('GLX_Y_INVERTED_EXT',0x20D4)
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXBindTexImageEXT(dpy,drawable,buffer,attrib_list):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.c_int)
def glXReleaseTexImageEXT(dpy,drawable,buffer):pass
