'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_compute_variable_group_size'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_compute_variable_group_size',error_checker=_errors._error_checker)
GL_MAX_COMPUTE_FIXED_GROUP_INVOCATIONS_ARB=_C('GL_MAX_COMPUTE_FIXED_GROUP_INVOCATIONS_ARB',0x90EB)
GL_MAX_COMPUTE_FIXED_GROUP_SIZE_ARB=_C('GL_MAX_COMPUTE_FIXED_GROUP_SIZE_ARB',0x91BF)
GL_MAX_COMPUTE_VARIABLE_GROUP_INVOCATIONS_ARB=_C('GL_MAX_COMPUTE_VARIABLE_GROUP_INVOCATIONS_ARB',0x9344)
GL_MAX_COMPUTE_VARIABLE_GROUP_SIZE_ARB=_C('GL_MAX_COMPUTE_VARIABLE_GROUP_SIZE_ARB',0x9345)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glDispatchComputeGroupSizeARB(num_groups_x,num_groups_y,num_groups_z,group_size_x,group_size_y,group_size_z):pass
