'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_draw_buffers'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_draw_buffers',error_checker=_errors._error_checker)
GL_DRAW_BUFFER0_ATI=_C('GL_DRAW_BUFFER0_ATI',0x8825)
GL_DRAW_BUFFER10_ATI=_C('GL_DRAW_BUFFER10_ATI',0x882F)
GL_DRAW_BUFFER11_ATI=_C('GL_DRAW_BUFFER11_ATI',0x8830)
GL_DRAW_BUFFER12_ATI=_C('GL_DRAW_BUFFER12_ATI',0x8831)
GL_DRAW_BUFFER13_ATI=_C('GL_DRAW_BUFFER13_ATI',0x8832)
GL_DRAW_BUFFER14_ATI=_C('GL_DRAW_BUFFER14_ATI',0x8833)
GL_DRAW_BUFFER15_ATI=_C('GL_DRAW_BUFFER15_ATI',0x8834)
GL_DRAW_BUFFER1_ATI=_C('GL_DRAW_BUFFER1_ATI',0x8826)
GL_DRAW_BUFFER2_ATI=_C('GL_DRAW_BUFFER2_ATI',0x8827)
GL_DRAW_BUFFER3_ATI=_C('GL_DRAW_BUFFER3_ATI',0x8828)
GL_DRAW_BUFFER4_ATI=_C('GL_DRAW_BUFFER4_ATI',0x8829)
GL_DRAW_BUFFER5_ATI=_C('GL_DRAW_BUFFER5_ATI',0x882A)
GL_DRAW_BUFFER6_ATI=_C('GL_DRAW_BUFFER6_ATI',0x882B)
GL_DRAW_BUFFER7_ATI=_C('GL_DRAW_BUFFER7_ATI',0x882C)
GL_DRAW_BUFFER8_ATI=_C('GL_DRAW_BUFFER8_ATI',0x882D)
GL_DRAW_BUFFER9_ATI=_C('GL_DRAW_BUFFER9_ATI',0x882E)
GL_MAX_DRAW_BUFFERS_ATI=_C('GL_MAX_DRAW_BUFFERS_ATI',0x8824)
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDrawBuffersATI(n,bufs):pass
