'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_gl_texture_cubemap_image'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_gl_texture_cubemap_image',error_checker=_errors._error_checker)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_X_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_X_KHR',0x30B4)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_KHR',0x30B6)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_KHR',0x30B8)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_X_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_X_KHR',0x30B3)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Y_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Y_KHR',0x30B5)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Z_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Z_KHR',0x30B7)

