'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_shading_language_include'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_shading_language_include',error_checker=_errors._error_checker)
GL_NAMED_STRING_LENGTH_ARB=_C('GL_NAMED_STRING_LENGTH_ARB',0x8DE9)
GL_NAMED_STRING_TYPE_ARB=_C('GL_NAMED_STRING_TYPE_ARB',0x8DEA)
GL_SHADER_INCLUDE_ARB=_C('GL_SHADER_INCLUDE_ARB',0x8DAE)
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),arrays.GLintArray)
def glCompileShaderIncludeARB(shader,count,path,length):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLcharArray)
def glDeleteNamedStringARB(namelen,name):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLcharArray,_cs.GLsizei,arrays.GLintArray,arrays.GLcharArray)
def glGetNamedStringARB(namelen,name,bufSize,stringlen,string):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLcharArray,_cs.GLenum,arrays.GLintArray)
def glGetNamedStringivARB(namelen,name,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLint,arrays.GLcharArray)
def glIsNamedStringARB(namelen,name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLcharArray,_cs.GLint,arrays.GLcharArray)
def glNamedStringARB(type,namelen,name,stringlen,string):pass
