'''OpenGL extension SGIS.point_parameters

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.point_parameters to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/point_parameters.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.point_parameters import *
from OpenGL.raw.GL.SGIS.point_parameters import _EXTENSION_NAME

def glInitPointParametersSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glPointParameterfvSGIS.params size not checked against 'pname'
glPointParameterfvSGIS=wrapper.wrapper(glPointParameterfvSGIS).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION