'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_EXT_visual_rating'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_EXT_visual_rating',error_checker=_errors._error_checker)
GLX_NONE_EXT=_C('GLX_NONE_EXT',0x8000)
GLX_NON_CONFORMANT_VISUAL_EXT=_C('GLX_NON_CONFORMANT_VISUAL_EXT',0x800D)
GLX_SLOW_VISUAL_EXT=_C('GLX_SLOW_VISUAL_EXT',0x8001)
GLX_VISUAL_CAVEAT_EXT=_C('GLX_VISUAL_CAVEAT_EXT',0x20)

